@@ -62,7 +62,7 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 $target %dowhat
 );
 
-$VERSION = '0.47.7'; # our $VERSION = '';
+$VERSION = '0.47.9'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT it a tool for detailed metadesign. It manages parametric explorations through the ESP-r building performance simulation platform and performs optimization by block coordinate descent.';
 
 #################################################################################
@@ -1154,7 +1154,7 @@ Sim::OPT.
 
 =head1 DESCRIPTION
 
-Sim::OPT is an optimization and morphing program that in principle may be used with any kind of simulation programs that can receive text files as input and emit text files ad output. Some of its optimization modules (Sim::OPT, Sim::OPT::Descent) pursue optimization by overlapping block coordinate descent (Gauss-Seidel method). Another optimization module (Sim::OPT::Takechange), that can be used optionally, seeks for the least explored search paths when exploring not-much-exploited exploited search spaces. Sim::OPT morphing module (Sim::OPT::Morph) manipulates text files by targeting specific variables position and applying to them generic interpolation rules. Another module (Sim::OPT::Parcoord3d) is dedicated to reporting and creating parallel coordinates plots in 3D.
+Sim::OPT is an optimization and morphing program that in principle may be used with any kind of simulation programs that can receive text files as input and emit text files ad output. Some of its optimization modules (Sim::OPT, Sim::OPT::Descent) pursue optimization by overlapping block coordinate descent (Gauss-Seidel method). Another optimization module (Sim::OPT::Takechange) seeks for the least explored search paths when exploring not-much-exploited exploited search spaces. The Sim::OPT morphing module (Sim::OPT::Morph) manipulates text files by targeting specific variables position and applying to them generic interpolation rules. The Sim::OPT::Parcoord3d module is dedicated to reporting and creating parallel coordinates plots in 3D.
 
 At a more specific level, Sim::OPT is aimed to the detailed metadesign of buildings through the ESP-r building performance simulation platform. Because of that, a working knowledge of ESP-r (http://www.esru.strath.ac.uk/Programs/ESP-r.htm) is presently necessary to use most functionalitues of OPT. (Note that ESP-r must be compiled for text, not graphics, and for Linux.) Sim::OPT features several morphing functions mapping the functions of the ESP-r platform and can manage it not only by manipulating text input files, but also through the shell.
 
@@ -1175,9 +1175,9 @@ The structure of the block searches is described through the variable "@sweeps".
 
 The number of iterations to be taken into account for each parameter for each case is specified in the "@varinumbers" variable. To specifiy that the parameters of the last example are to be tried for three values (iterations) each, @varinumbers has to be set to ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3, 5 => 3, 6 => 3 } ).
 
-Where Sim::OPT may be fit for the task? Where a certain exploration is complex and/or when it is to be confronted through decomposition, by dividing a problem in overallapping subproblems. In general, when approaching a certain problem manually, or in part manually and in part automatically, would take ages, and there aren't slick tools suitable to decomposition-based, simulation-based optimization available. When spending a day or two setting up a model may spare month of work.
+Where Sim::OPT may be fit for the task? Where a certain exploration is complex and/or when it is to be confronted through decomposition, by dividing a problem in overallapping subproblems. When there aren't slick tools suitable to decomposition-based, simulation-based optimization. When spending a day or two or three setting up a model may spare months of work.
 
-Where Sim::OPT may not be fit for the task? In its present state, due to its absolute crude interface, for quick shots at small explorations. There are many refined and user-friendly tools available for that.
+Where Sim::OPT may not be fit for the task? In its present state, due to its crude interface, for quick shots at small explorations.
 
 Gian Luca Brunetti
 
