@@ -48,7 +48,7 @@ $VERSION = '0.43.0'; # our $VERSION = '';
 
 sub descend 
 {
-	my $swap = shift; #say TOSHELL "swapINDESCEND: " . dump($swap);
+	my $swap = shift; #say TOFILE "swapINDESCEND: " . dump($swap);
 	my %dat = %$swap;
 	my @instances = @{ $dat{instances} }; #say "scalar(\@instances): " . scalar(@instances);
 	my $countcase = $dat{countcase}; #say "dump(\$countcase): " . dump($countcase); # IT WILL BE SHADOWED. CUT ZZZ
@@ -63,24 +63,24 @@ sub descend
 	@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
 	%vals = %main::vals; #say "dump(\%vals): " . dump(%vals);
 	
-	$mypath = $main::mypath;  #say TOSHELL "dumpINDESCEND(\$mypath): " . dump($mypath);
-	$exeonfiles = $main::exeonfiles; #say TOSHELL "dumpINDESCEND(\$exeonfiles): " . dump($exeonfiles);
+	$mypath = $main::mypath;  #say TOFILE "dumpINDESCEND(\$mypath): " . dump($mypath);
+	$exeonfiles = $main::exeonfiles; #say TOFILE "dumpINDESCEND(\$exeonfiles): " . dump($exeonfiles);
 	$generatechance = $main::generatechance; 
 	$file = $main::file;
 	$preventsim = $main::preventsim;
-	$fileconfig = $main::fileconfig; #say TOSHELL "dumpINDESCEND(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
+	$fileconfig = $main::fileconfig; #say TOFILE "dumpINDESCEND(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
 	$outfile = $main::outfile;
-	$toshell = $main::toshell;
+	$tofile = $main::tofile;
 	$report = $main::report;
 	$simnetwork = $main::simnetwork;
 	
 	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!";  
-	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
+	open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!";  
+	$tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
 	say "\nNow in Sim::OPT::Descend.\n";
 	say $tee "\n#Now in Sim::OPT::Descend.\n";
 	
-	#say TOSHELL "dump(\$repfile): " . dump($repfile); 
+	#say TOFILE "dump(\$repfile): " . dump($repfile); 
 	%dowhat = %main::dowhat;
 
 	%simtitles = %main::simtitles; #say "dumpINDESCEND(\@simtitles): " . dump(@simtitles);
@@ -106,14 +106,14 @@ sub descend
 	my @simstruct = @{ $dirfiles{simstruct} }; #say "dump(\@simstruct): " . dump(@simstruct);
 	my @morphcases = @{ $dirfiles{morphcases} };
 	my @morphstruct = @{ $dirfiles{morphstruct} };
-	my @retcases = @{ $dirfiles{retcases} }; say TOSHELL "dumpINDESCEND2(\@retcases): " . dump(@retcases);
-	my @retstruct = @{ $dirfiles{retstruct} }; say TOSHELL"dump(\@retstruct): " . dump(@retstruct);
-	my @repcases = @{ $dirfiles{repcases} };  say TOSHELL"dumpINDESCEND(\@repcases): " . dump(@repcases);
-	my @repstruct = @{ $dirfiles{repstruct} }; say TOSHELL"dumpINDESCEND(\@repstruct): " . dump(@repstruct);
-	my @mergecases = @{ $dirfiles{mergecases} }; say TOSHELL"dumpINDESCEND(\@mergecases): " . dump(@mergecases);
-	my @mergestruct = @{ $dirfiles{mergestruct} }; say TOSHELL"dumpINDESCEND(\@mergestruct): " . dump(@mergestruct);
-	my @descendcases = @{ $dirfiles{descendcases} }; say TOSHELL"dumpINDESCEND(\@descendcases): " . dump(@descendcases);
-	my @descendstruct = @{ $dirfiles{descendstruct} }; say TOSHELL"dumpINDESCEND(\@descendstruct): " . dump(@descendstruct);
+	my @retcases = @{ $dirfiles{retcases} }; say TOFILE "dumpINDESCEND2(\@retcases): " . dump(@retcases);
+	my @retstruct = @{ $dirfiles{retstruct} }; say TOFILE"dump(\@retstruct): " . dump(@retstruct);
+	my @repcases = @{ $dirfiles{repcases} };  say TOFILE"dumpINDESCEND(\@repcases): " . dump(@repcases);
+	my @repstruct = @{ $dirfiles{repstruct} }; say TOFILE"dumpINDESCEND(\@repstruct): " . dump(@repstruct);
+	my @mergecases = @{ $dirfiles{mergecases} }; say TOFILE"dumpINDESCEND(\@mergecases): " . dump(@mergecases);
+	my @mergestruct = @{ $dirfiles{mergestruct} }; say TOFILE"dumpINDESCEND(\@mergestruct): " . dump(@mergestruct);
+	my @descendcases = @{ $dirfiles{descendcases} }; say TOFILE"dumpINDESCEND(\@descendcases): " . dump(@descendcases);
+	my @descendstruct = @{ $dirfiles{descendstruct} }; say TOFILE"dumpINDESCEND(\@descendstruct): " . dump(@descendstruct);
 	
 	my $morphlist = $dirfiles{morphlist}; #say "dump(\$dat{morphlist}): " . dump($dat{morphlist});
 	my $morphblock = $dirfiles{morphblock};
@@ -121,14 +121,14 @@ sub descend
 	my $simblock = $dirfiles{simblock};
 	my $retlist = $dirfiles{retlist};
 	my $retblock = $dirfiles{retblock};
-	my $replist = $dirfiles{replist}; say TOSHELL"dumpINDESCEND(\$replist): " . dump($replist);
-	my $repblock = $dirfiles{repblock}; say TOSHELL"dumpINDESCEND(\$repblock): " . dump($repblock);
-	my $descendlist = $dirfiles{descendlist}; say TOSHELL"dumpINDESCEND(\$descendlist): " . dump($descendlist);
-	my $descendblock = $dirfiles{descendblock}; say TOSHELL"dumpINDESCEND(\$descendblock): " . dump($descendblock);
+	my $replist = $dirfiles{replist}; say TOFILE"dumpINDESCEND(\$replist): " . dump($replist);
+	my $repblock = $dirfiles{repblock}; say TOFILE"dumpINDESCEND(\$repblock): " . dump($repblock);
+	my $descendlist = $dirfiles{descendlist}; say TOFILE"dumpINDESCEND(\$descendlist): " . dump($descendlist);
+	my $descendblock = $dirfiles{descendblock}; say TOFILE"dumpINDESCEND(\$descendblock): " . dump($descendblock);
 	
-	my $skipfile = $vals{skipfile}; say TOSHELL "dump(\$skipfile): " . dump($skipfile);
-	my $skipsim = $vals{skipsim}; say TOSHELL "dump(\$skipsim): " . dump($skipsim);
-	my $skipreport = $vals{skipreport}; say TOSHELL "dump(\$skipreport): " . dump($skipreport);
+	my $skipfile = $vals{skipfile}; say TOFILE "dump(\$skipfile): " . dump($skipfile);
+	my $skipsim = $vals{skipsim}; say TOFILE "dump(\$skipsim): " . dump($skipsim);
+	my $skipreport = $vals{skipreport}; say TOFILE "dump(\$skipreport): " . dump($skipreport);
 		
 	#my $getpars = shift;
 	#eval( $getpars );
@@ -141,49 +141,49 @@ sub descend
 	my $instance = $instances[0]; # THIS WOULD HAVE TO BE A LOOP HERE TO MIX ALL THE MERGECASES!!! ### ZZZ
 	
 	my %d = %{$instance};
-	my $countcase = $d{countcase}; say TOSHELL "dump(\$countcase): " . dump($countcase);
-	my $countblock = $d{countblock}; say TOSHELL "dump(\$countblock): " . dump($countblock);
-	my @miditers = @{ $d{miditers} }; say TOSHELL "BEGINDESCENDdump(\@miditers): " . dump(@miditers);
-	my @winneritems = @{ $d{winneritems} }; say TOSHELL "dumpIN( \@winneritems) " . dump(@winneritems);
-	my $countvar = $d{countvar}; say TOSHELL "dump(\$countvar): " . dump($countvar);
-	my $countstep = $d{countstep}; say TOSHELL "dump(\$countstep): " . dump($countstep);						
-	my $to = $d{to}; say TOSHELL "dump(\$to): " . dump($to);
-	my $origin = $d{origin}; say TOSHELL "dump(\$origin): " . dump($origin);
-	my @uplift = @{ $d{uplift} }; say TOSHELL "dump(\@uplift): " . dump(@uplift);
+	my $countcase = $d{countcase}; say TOFILE "dump(\$countcase): " . dump($countcase);
+	my $countblock = $d{countblock}; say TOFILE "dump(\$countblock): " . dump($countblock);
+	my @miditers = @{ $d{miditers} }; say TOFILE "BEGINDESCENDdump(\@miditers): " . dump(@miditers);
+	my @winneritems = @{ $d{winneritems} }; say TOFILE "dumpIN( \@winneritems) " . dump(@winneritems);
+	my $countvar = $d{countvar}; say TOFILE "dump(\$countvar): " . dump($countvar);
+	my $countstep = $d{countstep}; say TOFILE "dump(\$countstep): " . dump($countstep);						
+	my $to = $d{to}; say TOFILE "dump(\$to): " . dump($to);
+	my $origin = $d{origin}; say TOFILE "dump(\$origin): " . dump($origin);
+	my @uplift = @{ $d{uplift} }; say TOFILE "dump(\@uplift): " . dump(@uplift);
 	#eval($getparshere);
 	
-	my $skip = $vals{$countvar}{skip}; say TOSHELL "dumpinreport(\$skip): " . dump($skip);
+	my $skip = $vals{$countvar}{skip}; say TOFILE "dumpinreport(\$skip): " . dump($skip);
 	
-	my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); say TOSHELL "dump(\$rootname): " . dump($rootname);
-	my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); say TOSHELL "dumpIN( \@blockelts) " . dump(@blockelts);
-	my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  say TOSHELL "dumpIN( \@blocks) " . dump(@blocks);
-	my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); say TOSHELL "dump(\$toitem): " . dump($toitem);
-	my $from = Sim::OPT::getline($toitem); say TOSHELL "dumpIN(\$from): " . dump($from);
-	my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); say TOSHELL "dumpIN---(\%varnums): " . dump(%varnums); 
-	my %mids = Sim::OPT::getcase(\@miditers, $countcase); say TOSHELL "dumpIN---(\%mids): " . dump(%mids); 
+	my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); say TOFILE "dump(\$rootname): " . dump($rootname);
+	my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); say TOFILE "dumpIN( \@blockelts) " . dump(@blockelts);
+	my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  say TOFILE "dumpIN( \@blocks) " . dump(@blocks);
+	my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); say TOFILE "dump(\$toitem): " . dump($toitem);
+	my $from = Sim::OPT::getline($toitem); say TOFILE "dumpIN(\$from): " . dump($from);
+	my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); say TOFILE "dumpIN---(\%varnums): " . dump(%varnums); 
+	my %mids = Sim::OPT::getcase(\@miditers, $countcase); say TOFILE "dumpIN---(\%mids): " . dump(%mids); 
 	#eval($getfly);
 	
-	my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); say TOSHELL "dump(\$stepsvar): " . dump($stepsvar); 
-	my $varnumber = $countvar; say TOSHELL "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
+	my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); say TOFILE "dump(\$stepsvar): " . dump($stepsvar); 
+	my $varnumber = $countvar; say TOFILE "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
 	my $contblocksplus = ($countblock + 1);
 	my $countcaseplus = ($countcase + 1);
 	
 	say $tee "Descending into case $countcaseplus, block $contblocksplus.";
 
-	my @columns_to_report = @{ $reporttempsdata[1] };  say TOSHELL "dump(\@columns_to_report): " . dump(@columns_to_report); 
-	my $number_of_columns_to_report = scalar(@columns_to_report); say TOSHELL "dump(\$number_of_columns_to_report): " . dump($number_of_columns_to_report); 
-	my $number_of_dates_to_mix = scalar(@simtitles); say TOSHELL "dump(\$number_of_dates_to_mix): " . dump($number_of_dates_to_mix); 
-	my @dates                    = @simtitles; say TOSHELL "dump(\@dates): " . dump(@dates); 
+	my @columns_to_report = @{ $reporttempsdata[1] };  say TOFILE "dump(\@columns_to_report): " . dump(@columns_to_report); 
+	my $number_of_columns_to_report = scalar(@columns_to_report); say TOFILE "dump(\$number_of_columns_to_report): " . dump($number_of_columns_to_report); 
+	my $number_of_dates_to_mix = scalar(@simtitles); say TOFILE "dump(\$number_of_dates_to_mix): " . dump($number_of_dates_to_mix); 
+	my @dates                    = @simtitles; say TOFILE "dump(\@dates): " . dump(@dates); 
 
-	my $cleanmixed = "$repfile-clean.csv"; say TOSHELL "dump(\$cleanmixed): " . dump($cleanmixed); 
+	my $cleanmixed = "$repfile-clean.csv"; say TOFILE "dump(\$cleanmixed): " . dump($cleanmixed); 
 	my $throwclean = $cleanmixed; $throwclean =~ s/\.csv//;
-	my $selectmixed = "$throwclean-select.csv"; say TOSHELL "dump(\$selectmixed): " . dump($selectmixed); 
+	my $selectmixed = "$throwclean-select.csv"; say TOFILE "dump(\$selectmixed): " . dump($selectmixed); 
 	
 	sub cleanselect
 	{ 	# IT CLEANS THE MIXED FILE AND SELECTS SOME COLUMNS, THEN COPIES THEM IN ANOTHER FILE
 		say $tee "Cleaning results for case $countcaseplus, block $contblocksplus.";
-		open( MIXFILE, $repfile ) or die( "$!" ); say TOSHELL "dump(\$repfile IN SUB cleanselect): " . dump($repfile); 
-		my @lines = <MIXFILE>; say TOSHELL "dump(MIXFILE \@lines): " . dump(@lines); 
+		open( MIXFILE, $repfile ) or die( "$!" ); say TOFILE "dump(\$repfile IN SUB cleanselect): " . dump($repfile); 
+		my @lines = <MIXFILE>; say TOFILE "dump(MIXFILE \@lines): " . dump(@lines); 
 		close MIXFILE;
 		open( CLEANMIXED, ">$cleanmixed" ) or die( "$!" );
 		foreach my $line ( @lines )
@@ -197,7 +197,7 @@ sub descend
 	
 		# IT SELECTS SOME COLUMNS AND COPIES THEM IN ANOTHER FILE
 		open( CLEANMIXED, $cleanmixed ) or die( "$!" );
-		my @lines = <CLEANMIXED>; say TOSHELL "dump(CLEANMIXED \@lines): " . dump(@lines); 
+		my @lines = <CLEANMIXED>; say TOFILE "dump(CLEANMIXED \@lines): " . dump(@lines); 
 		close CLEANMIXED;
 		
 		open( SELECTEDMIXED, ">$selectmixed" ) or die( "$!" );
@@ -239,12 +239,12 @@ sub descend
 	&cleanselect();
 	
 	my $throw = $selectmixed; $throw =~ s/\.csv//;
-	my $weight = "$throw-weight.csv"; say TOSHELL "dump(\$weight): " . dump($weight);  # THIS WILL HOST PARTIALLY SCALED VALUES, MADE POSITIVE AND WITH A CEILING OF 1
+	my $weight = "$throw-weight.csv"; say TOFILE "dump(\$weight): " . dump($weight);  # THIS WILL HOST PARTIALLY SCALED VALUES, MADE POSITIVE AND WITH A CEILING OF 1
 	sub weight
 	{	
 		say $tee "Scaling results for case $countcaseplus, block $contblocksplus.";
-		open( SELECTEDMIXED, $selectmixed ) or die( "$!" ); say TOSHELL "dump(\$selectmixed IN SUB weight ): " . dump($selectmixed);
-		my @lines = <SELECTEDMIXED>; say TOSHELL "dump(SELECTEDMIXED \@lines): " . dump(@lines); 
+		open( SELECTEDMIXED, $selectmixed ) or die( "$!" ); say TOFILE "dump(\$selectmixed IN SUB weight ): " . dump($selectmixed);
+		my @lines = <SELECTEDMIXED>; say TOFILE "dump(SELECTEDMIXED \@lines): " . dump(@lines); 
 		close SELECTEDMIXED;
 		my $counterline = 0;
 		open( WEIGHT, ">$weight" ) or die( "$!" );
@@ -262,14 +262,14 @@ sub descend
 			{
 				if ( Sim::OPT::odd($countel) )
 				{
-					push ( @{$containerone[$countcol]}, $elt); #print TOSHELL "ELT: $elt\n";
+					push ( @{$containerone[$countcol]}, $elt); #print TOFILE "ELT: $elt\n";
 					$countcol++;
 				}
 				push (@containernames, $touse);
 				$countel++;
 			}
 		} 
-		say TOSHELL "dump(SELECTEDMIXED \@containernames): " . dump(@containernames); 
+		say TOFILE "dump(SELECTEDMIXED \@containernames): " . dump(@containernames); 
 			
 		my @containertwo;
 		my @containerthree;
@@ -296,26 +296,26 @@ sub descend
 				push (@maxes, "NOTHING1");
 			}
 					
-			print TOSHELL "MAXES: " . Dumper(@maxes) . "\n";
-			print TOSHELL "DUMPCOLUMN: " . Dumper(@column) . "\n";
+			print TOFILE "MAXES: " . Dumper(@maxes) . "\n";
+			print TOFILE "DUMPCOLUMN: " . Dumper(@column) . "\n";
 			
 			foreach my $el (@column)
 			{
 				my $eltrans;
 				if ( $maxes[$countcolm] != 0 )
 				{
-					print TOSHELL "\$weights[\$countcolm]: $weights[$countcolm]\n";
+					print TOFILE "\$weights[\$countcolm]: $weights[$countcolm]\n";
 					$eltrans = ( $el / $maxes[$countcolm] ) ;
 				}
 				else
 				{
 					$eltrans = "NOTHING2" ;
 				}
-				push ( @{$containertwo[$countcolm]}, $eltrans) ; print TOSHELL "ELTRANS: $eltrans\n";
+				push ( @{$containertwo[$countcolm]}, $eltrans) ; print TOFILE "ELTRANS: $eltrans\n";
 			}
 			$countcolm++;
 		} 
-		print TOSHELL "CONTAINERTWO " . Dumper(@containertwo) . "\n";
+		print TOFILE "CONTAINERTWO " . Dumper(@containertwo) . "\n";
 				
 		my $countline = 0;
 		foreach my $line (@lines)
@@ -326,8 +326,8 @@ sub descend
 			foreach $eltref (@containertwo)
 			{
 				my @col =  @{$eltref};
-				my $max = max(@col); print TOSHELL "MAX IN SUB weight: $max\n";
-				my $min = min(@col); print TOSHELL "MIN IN SUB weight: $min\n";
+				my $max = max(@col); print TOFILE "MAX IN SUB weight: $max\n";
+				my $min = min(@col); print TOFILE "MIN IN SUB weight: $min\n";
 				my $floordistance = ($max - $min);
 				my $el = $col[$countline];
 				my $rescaledel;
@@ -367,7 +367,7 @@ sub descend
 			$counterline++;
 		}
 		close WEIGHT;
-		print TOSHELL "CONTAINERTHREE: " . Dumper(@containerthree) . "\n";
+		print TOFILE "CONTAINERTHREE: " . Dumper(@containerthree) . "\n";
 	}
 	&weight(); #
 	
@@ -375,10 +375,10 @@ sub descend
 	sub weighttwo
 	{
 		say $tee "Weighting results for case $countcaseplus, block $contblocksplus.";
-		open( WEIGHT, $weight ); say TOSHELL "dump(\$weight IN SUB weighttwo): " . dump($weight);
+		open( WEIGHT, $weight ); say TOFILE "dump(\$weight IN SUB weighttwo): " . dump($weight);
 		my @lines = <WEIGHT>;
 		close WEIGHT;
-		open( WEIGHTTWO, ">$weighttwo" ); say TOSHELL "dump(\$weighttwo): " . dump($weighttwo);
+		open( WEIGHTTWO, ">$weighttwo" ); say TOFILE "dump(\$weighttwo): " . dump($weighttwo);
 		my $counterline;
 		foreach my $line (@lines)
 		{
@@ -394,10 +394,10 @@ sub descend
 				my $newelt;
 				if ($counterelt > ( $#elts - $numberels ))
 				{
-					print TOSHELL "ELT: $elt\n";
-					$newelt = ( $elt * abs($weights[$counterin]) ); # print TOSHELL "NEWELT: $newelt\n";
-					print TOSHELL "ABS" . abs($weights[$counterin]) . "\n";
-					$sum = ( $sum + $newelt ) ; # print TOSHELL "SUM: $sum\n";
+					print TOFILE "ELT: $elt\n";
+					$newelt = ( $elt * abs($weights[$counterin]) ); # print TOFILE "NEWELT: $newelt\n";
+					print TOFILE "ABS" . abs($weights[$counterin]) . "\n";
+					$sum = ( $sum + $newelt ) ; # print TOFILE "SUM: $sum\n";
 					$counterin++;
 				}
 				$counterelt++;
@@ -424,14 +424,14 @@ sub descend
 	}
 	&weighttwo();	
 	
-	say TOSHELL "dump(\$repfile BEFORE SUB sortmixed): " . dump( $repfile );
-	my $sortmixed = "$repfile-sortmixed.csv"; say TOSHELL "dump(\$sortmixed BEFORE SUB sortmixed): " . dump( $sortmixed );
+	say TOFILE "dump(\$repfile BEFORE SUB sortmixed): " . dump( $repfile );
+	my $sortmixed = "$repfile-sortmixed.csv"; say TOFILE "dump(\$sortmixed BEFORE SUB sortmixed): " . dump( $sortmixed );
 	#if ($repfile) { $sortmixed = "$repfile-sortmixed.csv"; } else { die( "$!" ); } # globsAL!
 	sub sortmixed
 	{
 		say $tee "Processing results for case $countcaseplus, block $contblocksplus.";
-		open( WEIGHTTWO, $weighttwo ) or die( "$!" ); say TOSHELL "dump(\$weighttwo IN SUB sortmixed): " . dump($weighttwo);
-		open( SORTMIXED_, ">$sortmixed" ) or die( "$!" ); say TOSHELL "dump(\$sortmixed): " . dump($sortmixed);
+		open( WEIGHTTWO, $weighttwo ) or die( "$!" ); say TOFILE "dump(\$weighttwo IN SUB sortmixed): " . dump($weighttwo);
+		open( SORTMIXED_, ">$sortmixed" ) or die( "$!" ); say TOFILE "dump(\$sortmixed): " . dump($sortmixed);
 		my @lines = <WEIGHTTWO>;
 		close WEIGHTTWO;
 		my $count = 0;
@@ -440,7 +440,7 @@ sub descend
 			$_ = "$containernames[$count]," . "$_";
 			$count++;
 		}
-		say TOSHELL "TAKEOPTIMA--dump(\@lines): " . dump(@lines);
+		say TOFILE "TAKEOPTIMA--dump(\@lines): " . dump(@lines);
 		
 		my $line = $lines[0];
 		my @eltstemp = split(/,/, $line);
@@ -479,20 +479,20 @@ sub descend
 	{
 		#my $pass_signal = ""; # IF VOID, GAUSS SEIDEL METHOD. IF 0, JACOBI METHOD. ...
 		
-		#say TOSHELL `cat $sortmixed`;
-		#say TOSHELL "TAKEOPTIMA cat \$sortmixed: $sortmixed";
+		#say TOFILE `cat $sortmixed`;
+		#say TOFILE "TAKEOPTIMA cat \$sortmixed: $sortmixed";
 		
 		open( SORTMIXED_, $sortmixed ) or die( "$!" );
 		my @lines = <SORTMIXED_>;
 		close SORTMIXED_;
 		
-		my $winnerentry = $lines[0]; #ay TOSHELL "dump( IN SUB TAKEOPTIMA\$winnerentry): " . dump($winnerentry);
+		my $winnerentry = $lines[0]; #ay TOFILE "dump( IN SUB TAKEOPTIMA\$winnerentry): " . dump($winnerentry);
 		chomp $winnerentry;
 		
 		my @winnerelms = split(/\s+|,/, $winnerentry);
-		my $winnerline = $winnerelms[0]; say TOSHELL "dump(TAKEOPTIMA\$winnerline): " . dump($winnerline);
+		my $winnerline = $winnerelms[0]; say TOFILE "dump(TAKEOPTIMA\$winnerline): " . dump($winnerline);
 		my $winnerval = $winnerelms[$#winnerelms];
-		push ( @{ $uplift[$countcase][$countblock] }, $winnerval); say TOSHELL "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
+		push ( @{ $uplift[$countcase][$countblock] }, $winnerval); say TOFILE "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
 		
 		my $message = "$mypath/attention.txt";
 		open( MESSAGE, ">>$message");
@@ -517,12 +517,12 @@ sub descend
 		
 		my $copy = $winnerline;
 		$copy =~ s/$mypath\/$file//;
-		my @taken = Sim::OPT::extractcase("$copy", \%mids); say TOSHELL "TAKEOPTIMA--->taken: " . dump(@taken);
-		my $newtarget = $taken[0]; say TOSHELL "TAKEOPTIMA\$newtarget--->: $newtarget";
+		my @taken = Sim::OPT::extractcase("$copy", \%mids); say TOFILE "TAKEOPTIMA--->taken: " . dump(@taken);
+		my $newtarget = $taken[0]; say TOFILE "TAKEOPTIMA\$newtarget--->: $newtarget";
 		$newtarget =~ s/$mypath\///;
-		my %newcarrier = %{$taken[1]}; say TOSHELL "TAKEOPTIMA\%newcarrier--->" . dump(%newcarrier);
-		say TOSHELL "TAKEOPTIMA BEFORE->\@miditers: " . dump(@miditers);
-		%{ $miditers[$countcase] } = %newcarrier; say TOSHELL "TAKEOPTIMA AFTER->\@miditers: " . dump(@miditers);
+		my %newcarrier = %{$taken[1]}; say TOFILE "TAKEOPTIMA\%newcarrier--->" . dump(%newcarrier);
+		say TOFILE "TAKEOPTIMA BEFORE->\@miditers: " . dump(@miditers);
+		%{ $miditers[$countcase] } = %newcarrier; say TOFILE "TAKEOPTIMA AFTER->\@miditers: " . dump(@miditers);
 		
 		#say "2\$countcase : " . dump($countcase);
 		#say "2\@rootnames : " . dump(@rootnames);
@@ -534,12 +534,12 @@ sub descend
 		#say "2\@morphcases : " . dump(@morphcases);
 		#say "2\@morphstruct : " . dump(@morphstruct);
 		
-		say TOSHELL "TAKEOPTIMA FINAL ->\$countcase " . dump($countcase);
-		say TOSHELL "TAKEOPTIMA FINAL ->\$countblock " . dump($countblock);
-		say TOSHELL "TAKEOPTIMA FINAL ->\@miditers " . dump(@miditers);
-		say TOSHELL "TAKEOPTIMA FINAL ->\@winneritems " . dump(@winneritems);
-		say TOSHELL "TAKEOPTIMA FINAL ->\%dirfiles " . dump(%dirfiles);
-		say TOSHELL "TAKEOPTIMA FINAL ->\@uplift " . dump(@uplift);
+		say TOFILE "TAKEOPTIMA FINAL ->\$countcase " . dump($countcase);
+		say TOFILE "TAKEOPTIMA FINAL ->\$countblock " . dump($countblock);
+		say TOFILE "TAKEOPTIMA FINAL ->\@miditers " . dump(@miditers);
+		say TOFILE "TAKEOPTIMA FINAL ->\@winneritems " . dump(@winneritems);
+		say TOFILE "TAKEOPTIMA FINAL ->\%dirfiles " . dump(%dirfiles);
+		say TOFILE "TAKEOPTIMA FINAL ->\@uplift " . dump(@uplift);
 		
 		$countblock++; ### !!!
 		
@@ -570,7 +570,7 @@ sub descend
 		}
 		else
 		{
-			push ( @{ $winneritems[$countcase][$countblock] }, $newtarget); say TOSHELL "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
+			push ( @{ $winneritems[$countcase][$countblock] }, $newtarget); say TOFILE "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
 			"#Leaving case " . ($countcase + 1) . ", block " . ($countblock + 1) . " and descending!\ ";
 			Sim::OPT::callcase( { countcase => $countcase, countblock => $countblock, 
 			miditers => \@miditers,  winneritems => \@winneritems, 
@@ -579,7 +579,7 @@ sub descend
 	}
 	&takeoptima();
 	close OUTFILE;
-	close TOSHELL;
+	close TOFILE;
 }    # END SUB descend
 
 1;
