@@ -46,35 +46,35 @@ $VERSION = '0.47'; # our $VERSION = '';
 
 sub retrieve
 {	
-	my $swap = shift; #say TOSHELL "swapINRETRIEVE: " . dump($swap);
+	my $swap = shift; #say TOFILE "swapINRETRIEVE: " . dump($swap);
 	my %dat = %$swap;
 	my @instances = @{ $dat{instances} }; #say "scalar(\@instances): " . scalar(@instances);
-	my $countcase = $dat{countcase}; #say TOSHELL "dump(\$countcase): " . dump($countcase); # IT WILL BE SHADOWED. CUT ZZZ
-	my $countblock = $dat{countblock}; #say TOSHELL "dump(\$countblock): " . dump($countblock); # IT WILL BE SHADOWED. CUT ZZZ		
+	my $countcase = $dat{countcase}; #say TOFILE "dump(\$countcase): " . dump($countcase); # IT WILL BE SHADOWED. CUT ZZZ
+	my $countblock = $dat{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock); # IT WILL BE SHADOWED. CUT ZZZ		
 	my %dirfiles = %{ $dat{dirfiles} }; #say "dump(\%dirfiles): " . dump(%dirfiles); 
 		
 	$configfile = $main::configfile; #say "dump(\$configfile): " . dump($configfile);
-	@sweeps = @main::sweeps; #say TOSHELL "dump(\@sweeps): " . dump(@sweeps);
+	@sweeps = @main::sweeps; #say TOFILE "dump(\@sweeps): " . dump(@sweeps);
 	@varinumbers = @main::varinumbers; #say "dump(\@varinumbers): " . dump(@varinumbers);
 	@mediumiters = @main::mediumiters;
 	@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
 	%vals = %main::vals; #say "dump(\%vals): " . dump(%vals);
 	
-	$mypath = $main::mypath;  #say TOSHELL "dumpINRETRIEVE(\$mypath): " . dump($mypath);
-	$exeonfiles = $main::exeonfiles; #say TOSHELL "dumpINRETRIEVE(\$exeonfiles): " . dump($exeonfiles);
+	$mypath = $main::mypath;  #say TOFILE "dumpINRETRIEVE(\$mypath): " . dump($mypath);
+	$exeonfiles = $main::exeonfiles; #say TOFILE "dumpINRETRIEVE(\$exeonfiles): " . dump($exeonfiles);
 	$generatechance = $main::generatechance; 
 	$file = $main::file;
 	$preventsim = $main::preventsim;
-	$fileconfig = $main::fileconfig; #say TOSHELL "dumpINRETRIEVE(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
+	$fileconfig = $main::fileconfig; #say TOFILE "dumpINRETRIEVE(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
 	$outfile = $main::outfile;
-	$toshell = $main::toshell;
+	$tofile = $main::tofile;
 	$report = $main::report;
 	$simnetwork = $main::simnetwork;
 	
-	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
+	$tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
 	
 	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
+	open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!"; 
 	say "\nNow in Sim::OPT::Report::retrieve.\n";
 	say $tee "\n#Now in Sim::OPT::Report_retrieve.\n";
 	
@@ -135,32 +135,32 @@ sub retrieve
 	my $countinstance = 0;
 	foreach my $instance (@instances)
 	{
-		say TOSHELL "\nNow in Sim::OPT::Retrieve. INSTANCES\n";
+		say TOFILE "\nNow in Sim::OPT::Retrieve. INSTANCES\n";
 		my %d = %{$instance};
-		my $countcase = $d{countcase}; #say TOSHELL "dump(\$countcase): " . dump($countcase);
-		my $countblock = $d{countblock}; #say TOSHELL "dump(\$countblock): " . dump($countblock);
+		my $countcase = $d{countcase}; #say TOFILE "dump(\$countcase): " . dump($countcase);
+		my $countblock = $d{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock);
 		my @miditers = @{ $d{miditers} }; #say $tee "dump(\@miditers): " . dump(@miditers);
-		my @winneritems = @{ $d{winneritems} }; #say TOSHELL "dumpIN( \@winneritems) " . dump(@winneritems);
-		my $countvar = $d{countvar}; #say TOSHELL "dump(\$countvar): " . dump($countvar);
-		my $countstep = $d{countstep}; #say TOSHELL "dump(\$countstep): " . dump($countstep);						
-		my $to = $d{to}; #say TOSHELL "dump(\$to): " . dump($to);
-		my $origin = $d{origin}; #say TOSHELL "dump(\$origin): " . dump($origin);
-		my @uplift = @{ $d{uplift} }; #say TOSHELL "dump(\@uplift): " . dump(@uplift);
+		my @winneritems = @{ $d{winneritems} }; #say TOFILE "dumpIN( \@winneritems) " . dump(@winneritems);
+		my $countvar = $d{countvar}; #say TOFILE "dump(\$countvar): " . dump($countvar);
+		my $countstep = $d{countstep}; #say TOFILE "dump(\$countstep): " . dump($countstep);						
+		my $to = $d{to}; #say TOFILE "dump(\$to): " . dump($to);
+		my $origin = $d{origin}; #say TOFILE "dump(\$origin): " . dump($origin);
+		my @uplift = @{ $d{uplift} }; #say TOFILE "dump(\@uplift): " . dump(@uplift);
 		#eval($getparshere);
 		
 		my $skip = $vals{$countvar}{skip}; #say $tee "dumpinreport(\$skip): " . dump($skip);
 		
-		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOSHELL "dump(\$rootname): " . dump($rootname);
-		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOSHELL "dumpIN( \@blockelts) " . dump(@blockelts);
-		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOSHELL "dumpIN( \@blocks) " . dump(@blocks);
-		my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); #say TOSHELL "dump(\$toitem): " . dump($toitem);
+		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOFILE "dump(\$rootname): " . dump($rootname);
+		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOFILE "dumpIN( \@blockelts) " . dump(@blockelts);
+		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOFILE "dumpIN( \@blocks) " . dump(@blocks);
+		my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); #say TOFILE "dump(\$toitem): " . dump($toitem);
 		my $from = Sim::OPT::getline($toitem); #say $tee "dumpIN(\$from): " . dump($from);
-		my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); #say TOSHELL "dumpIN---(\%varnums): " . dump(%varnums); 
-		my %mids = Sim::OPT::getcase(\@miditers, $countcase); #say TOSHELL "dumpIN---(\%mids): " . dump(%mids); 
+		my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); #say TOFILE "dumpIN---(\%varnums): " . dump(%varnums); 
+		my %mids = Sim::OPT::getcase(\@miditers, $countcase); #say TOFILE "dumpIN---(\%mids): " . dump(%mids); 
 		#eval($getfly);
 		
-		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOSHELL "dump(\$stepsvar): " . dump($stepsvar); 
-		my $varnumber = $countvar; #say TOSHELL "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
+		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOFILE "dump(\$stepsvar): " . dump($stepsvar); 
+		my $varnumber = $countvar; #say TOFILE "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
 		
 		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); #say $tee "\$numberof_simtools " . dump( $numberof_simtools );
 		
@@ -274,10 +274,10 @@ ZZZ
 						if ($exeonfiles eq "y") 
 						{ 
 							say "Retrieving comfort results.";
-							say TOSHELL "#Retrieving comfort results.";
+							say TOFILE "#Retrieving comfort results.";
 							print `$printthis`;
 						}
-						print TOSHELL "
+						print TOFILE "
 		#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
 		$printthis";
 					}
@@ -428,7 +428,7 @@ TTT
 										my $semaphorestop2 = $datarep{semaphorestop2}; say $tee "\$semaphorestop2 " . dump($semaphorestop2); 
 										my $textpattern = $datarep{textpattern}; say $tee "\$textpattern " . dump($textpattern); 
 										my $afterlines = $datarep{afterlines}; say $tee "\$afterlines " . dump($afterlines); 
-										my $retfile = "$resfile-$reporttitle-$themereport.grt"; #say $tee "\$retfile " . dump($retfile); say TOSHELL "\$retfile " . dump($retfile); say TOSHELL "\$retfile " . dump($retfile);
+										my $retfile = "$resfile-$reporttitle-$themereport.grt"; #say $tee "\$retfile " . dump($retfile); say TOFILE "\$retfile " . dump($retfile); say TOFILE "\$retfile " . dump($retfile);
 										
 										$retstruct[$countcase][$countblock][ $countinstance ][$counttheme][$countreport][$countitem][$counttool] = $retfile;
 										print RETBLOCK "$retfile\n";
@@ -528,7 +528,7 @@ TTT
 									my $semaphorestop2 = $datarep{semaphorestop2}; say $tee "\$semaphorestop2 " . dump($semaphorestop2); 
 									my $textpattern = $datarep{textpattern}; say $tee "\$textpattern " . dump($textpattern); 
 									my $afterlines = $datarep{afterlines}; say $tee "\$afterlines " . dump($afterlines);  
-									say TOSHELL "\$retfile " . dump($retfile); say TOSHELL "\$retfile " . dump($retfile);
+									say TOFILE "\$retfile " . dump($retfile); say TOFILE "\$retfile " . dump($retfile);
 									
 									print RETBLOCK "$retfile\n";
 	
@@ -568,9 +568,9 @@ TTT
 		$countinstance++;
 	}
 	print `rm -f $mypath/*.par`;
-	print TOSHELL "rm -f $mypath/*.par\n";
+	print TOFILE "rm -f $mypath/*.par\n";
 	close OUTFILE;
-	close TOSHELL;
+	close TOFILE;
 	close RETLIST;
 	close RETBLOCK;
 	say $tee "INEXIT \@retcases " . dump( @retcases ); 
@@ -582,7 +582,7 @@ TTT
 
 sub report # This function retrieves the results of interest from the texts files created by the "retrieve" function
 {
-	my $swap = shift; #say TOSHELL "swapINDESCEND: " . dump($swap);
+	my $swap = shift; #say TOFILE "swapINDESCEND: " . dump($swap);
 	my %dat = %$swap;
 	my @instances = @{ $dat{instances} }; #say "scalar(\@instances): " . scalar(@instances);
 	my $countcase = $dat{countcase}; #say "dump(\$countcase): " . dump($countcase); # IT WILL BE SHADOWED. CUT ZZZ
@@ -596,23 +596,23 @@ sub report # This function retrieves the results of interest from the texts file
 	@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
 	%vals = %main::vals; #say "dump(\%vals): " . dump(%vals);
 	
-	$mypath = $main::mypath;  #say TOSHELL "dumpINDESCEND(\$mypath): " . dump($mypath);
-	$exeonfiles = $main::exeonfiles; #say TOSHELL "dumpINDESCEND(\$exeonfiles): " . dump($exeonfiles);
+	$mypath = $main::mypath;  #say TOFILE "dumpINDESCEND(\$mypath): " . dump($mypath);
+	$exeonfiles = $main::exeonfiles; #say TOFILE "dumpINDESCEND(\$exeonfiles): " . dump($exeonfiles);
 	$generatechance = $main::generatechance; 
 	$file = $main::file;
 	$preventsim = $main::preventsim;
-	$fileconfig = $main::fileconfig; #say TOSHELL "dumpINDESCEND(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
+	$fileconfig = $main::fileconfig; #say TOFILE "dumpINDESCEND(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
 	$outfile = $main::outfile;
-	$toshell = $main::toshell;
+	$tofile = $main::tofile;
 	$report = $main::report;
 	$simnetwork = $main::simnetwork;
 	
-	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
+	$tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
 	
 	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!";  
+	open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!";  
 	say "\nNow in Sim::OPT::Report::report.\n";
-	say TOSHELL "\n#Now in Sim::OPT::Report::report.\n";
+	say TOFILE "\n#Now in Sim::OPT::Report::report.\n";
 	
 	%dowhat = %main::dowhat;
 
@@ -638,21 +638,21 @@ sub report # This function retrieves the results of interest from the texts file
 	my @simstruct = @{ $dirfiles{simstruct} }; #say "dump(\@simstruct): " . dump(@simstruct);
 	my @INREPORT = @{ $dirfiles{morphcases} };
 	my @morphstruct = @{ $dirfiles{morphstruct} };
-	my @retcases = @{ $dirfiles{retcases} }; say TOSHELL "dumpINREPORT::report(\@retcases): " . dump(@retcases); 
-	my @retstruct = @{ $dirfiles{retstruct} }; say TOSHELL "dumpINREPORT::report(\@retstruct): " . dump(@retstruct);
+	my @retcases = @{ $dirfiles{retcases} }; say TOFILE "dumpINREPORT::report(\@retcases): " . dump(@retcases); 
+	my @retstruct = @{ $dirfiles{retstruct} }; say TOFILE "dumpINREPORT::report(\@retstruct): " . dump(@retstruct);
 	my @repcases = @{ $dirfiles{repcases} };
 	my @repstruct = @{ $dirfiles{repstruct} };
 	my @mergecases = @{ $dirfiles{mergecases} };
 	my @mergestruct = @{ $dirfiles{mergestruct} };
 	my @descendcases = @{ $dirfiles{descendcases} };
 	my @descendstruct = @{ $dirfiles{descendstruct} };
-	my @notecases = @{ $dirfiles{notecases} }; say TOSHELL "dumpINREPORT::report(\@notecases): " . dump(@notecases);
+	my @notecases = @{ $dirfiles{notecases} }; say TOFILE "dumpINREPORT::report(\@notecases): " . dump(@notecases);
 	
 	my $morphlist = $dirfiles{morphlist}; #say "dump(\$dat{morphlist}): " . dump($dat{morphlist});
 	my $morphblock = $dirfiles{morphblock};
 	my $simlist = $dirfiles{simlist}; #say "dump(\$simlist): " . dump($simlist);
 	my $simblock = $dirfiles{simblock};
-	my $retlist = $dirfiles{retlist}; say TOSHELL "dumpINREPORT::report(\$retlist): " . dump($retlist); 
+	my $retlist = $dirfiles{retlist}; say TOFILE "dumpINREPORT::report(\$retlist): " . dump($retlist); 
 	my $retblock = $dirfiles{retblock};
 	my $replist = $dirfiles{replist};
 	my $repblock = $dirfiles{repblock};
@@ -668,33 +668,33 @@ sub report # This function retrieves the results of interest from the texts file
 	foreach my $instance (@instances)
 	{
 		my %d = %{$instance};
-		my $countcase = $d{countcase}; #say TOSHELL "dump(\$countcase): " . dump($countcase);
-		my $countblock = $d{countblock}; #say TOSHELL "dump(\$countblock): " . dump($countblock);
-		my @miditers = @{ $d{miditers} }; #say TOSHELL "dump(\@miditers): " . dump(@miditers);
-		my @winneritems = @{ $d{winneritems} }; #say TOSHELL "dumpIN( \@winneritems) " . dump(@winneritems);
-		my $countvar = $d{countvar}; #say TOSHELL "dump(\$countvar): " . dump($countvar);
-		my $countstep = $d{countstep}; #say TOSHELL "dump(\$countstep): " . dump($countstep);						
-		my $to = $d{to}; #say TOSHELL "dump(\$to): " . dump($to);
-		my $origin = $d{origin}; #say TOSHELL "dump(\$origin): " . dump($origin);
-		my @uplift = @{ $d{uplift} }; #say TOSHELL "dump(\@uplift): " . dump(@uplift);
+		my $countcase = $d{countcase}; #say TOFILE "dump(\$countcase): " . dump($countcase);
+		my $countblock = $d{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock);
+		my @miditers = @{ $d{miditers} }; #say TOFILE "dump(\@miditers): " . dump(@miditers);
+		my @winneritems = @{ $d{winneritems} }; #say TOFILE "dumpIN( \@winneritems) " . dump(@winneritems);
+		my $countvar = $d{countvar}; #say TOFILE "dump(\$countvar): " . dump($countvar);
+		my $countstep = $d{countstep}; #say TOFILE "dump(\$countstep): " . dump($countstep);						
+		my $to = $d{to}; #say TOFILE "dump(\$to): " . dump($to);
+		my $origin = $d{origin}; #say TOFILE "dump(\$origin): " . dump($origin);
+		my @uplift = @{ $d{uplift} }; #say TOFILE "dump(\@uplift): " . dump(@uplift);
 		
-		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOSHELL "dump(\$rootname): " . dump($rootname);
-		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOSHELL "dumpIN( \@blockelts) " . dump(@blockelts);
-		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOSHELL "dumpIN( \@blocks) " . dump(@blocks);
-		my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); #say TOSHELL "dump(\$toitem): " . dump($toitem);
-		my $from = Sim::OPT::getline($toitem); #say TOSHELL "dumpIN(\$from): " . dump($from);
-		my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); #say TOSHELL "dumpIN---(\%varnums): " . dump(%varnums); 
-		my %mids = Sim::OPT::getcase(\@miditers, $countcase); #say TOSHELL "dumpIN---(\%mids): " . dump(%mids); 
+		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOFILE "dump(\$rootname): " . dump($rootname);
+		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOFILE "dumpIN( \@blockelts) " . dump(@blockelts);
+		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOFILE "dumpIN( \@blocks) " . dump(@blocks);
+		my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); #say TOFILE "dump(\$toitem): " . dump($toitem);
+		my $from = Sim::OPT::getline($toitem); #say TOFILE "dumpIN(\$from): " . dump($from);
+		my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); #say TOFILE "dumpIN---(\%varnums): " . dump(%varnums); 
+		my %mids = Sim::OPT::getcase(\@miditers, $countcase); #say TOFILE "dumpIN---(\%mids): " . dump(%mids); 
 		
-		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOSHELL "dump(\$stepsvar): " . dump($stepsvar); 
-		my $varnumber = $countvar; #say TOSHELL "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
+		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOFILE "dump(\$stepsvar): " . dump($stepsvar); 
+		my $varnumber = $countvar; #say TOFILE "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
 
-		say TOSHELL "#Processing reports for case " . ($countcase + 1) . ", block " . ($countblock + 1);
+		say TOFILE "#Processing reports for case " . ($countcase + 1) . ", block " . ($countblock + 1);
 		
-		open( REPLIST, ">>$replist" ) or die( "$!" ); say TOSHELL "dump---(\$replist): " . dump($replist) . "\n\n";  
-		open( REPBLOCK, ">>$repblock" ) or die( "$!" ); say TOSHELL "dump---(\$repblock): " . dump($repblock) . "\n\n";
+		open( REPLIST, ">>$replist" ) or die( "$!" ); say TOFILE "dump---(\$replist): " . dump($replist) . "\n\n";  
+		open( REPBLOCK, ">>$repblock" ) or die( "$!" ); say TOFILE "dump---(\$repblock): " . dump($repblock) . "\n\n";
 		
-		$repfile = "$mypath/$file-report-$countcase-$countblock.txt";  say TOSHELL "dump---(\$repfile): " . dump($repfile) . "\n\n";
+		$repfile = "$mypath/$file-report-$countcase-$countblock.txt";  say TOFILE "dump---(\$repfile): " . dump($repfile) . "\n\n";
 		open( REPFILE, ">>$repfile") or die "Can't open $repfile $!";
 		
 		push ( @{ $repstruct[$countcase][$countblock] }, $repfile );
@@ -707,7 +707,7 @@ sub report # This function retrieves the results of interest from the texts file
 
 		#open( REPFILE, ">>$repfile") or die "Can't open $repfile $!";
 		
-		say TOSHELL "dump---(\%notecases): " . dump( %notecases ) . "\n\n";  
+		say TOFILE "dump---(\%notecases): " . dump( %notecases ) . "\n\n";  
 		
 		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); say $tee "\$numberof_simtools " . dump( $numberof_simtools );
 		
@@ -722,16 +722,16 @@ sub report # This function retrieves the results of interest from the texts file
 				foreach $ret_ref ( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } )
 				{
 					say $tee "\$ret_ref " . dump( $ret_ref );
-					%retitem = %$ret_ref; say TOSHELL "dump---(\@retitem): " . dump(@retitem) . "\n\n";  
-					my $retfile = $retitem{retfile}; say TOSHELL "dump---(\$retfile): " . dump($retfile) . "\n\n";  
-					my $reporttitle = $retitem{reporttitle}; say TOSHELL "dump---(\$reporttitle): " . dump($reporttitle) . "\n\n";  
-					my $themereport = $retitem{themereport}; say TOSHELL "dump---(\$themereport): " . dump($themereport) . "\n\n";  
-					my $semaphorego1 = $retitem{semaphorego1}; say TOSHELL "dump---(\$semaphorego1): " . dump($semaphorego1) . "\n\n";  
-					my $semaphorego2 = $retitem{semaphorego2}; say TOSHELL "dump---(\$semaphorego2): " . dump($semaphorego2) . "\n\n";  
-					my $semaphorestop1 = $retitem{semaphorestop1}; say TOSHELL "dump---(\$semaphorestop1): " . dump($semaphorestop1) . "\n\n";
-					my $semaphorestop2 = $retitem{semaphorestop2}; say TOSHELL "dump---(\$semaphorestop2): " . dump($semaphorestop2) . "\n\n";  
-					my $textpattern = $retitem{textpattern}; say TOSHELL "dump---(\$textpattern): " . dump($textpattern) . "\n\n";  
-					my $afterlines = $retitem{afterlines}; say TOSHELL "dump---(\$afterlines): " . dump($afterlines) . "\n\n";  
+					%retitem = %$ret_ref; say TOFILE "dump---(\@retitem): " . dump(@retitem) . "\n\n";  
+					my $retfile = $retitem{retfile}; say TOFILE "dump---(\$retfile): " . dump($retfile) . "\n\n";  
+					my $reporttitle = $retitem{reporttitle}; say TOFILE "dump---(\$reporttitle): " . dump($reporttitle) . "\n\n";  
+					my $themereport = $retitem{themereport}; say TOFILE "dump---(\$themereport): " . dump($themereport) . "\n\n";  
+					my $semaphorego1 = $retitem{semaphorego1}; say TOFILE "dump---(\$semaphorego1): " . dump($semaphorego1) . "\n\n";  
+					my $semaphorego2 = $retitem{semaphorego2}; say TOFILE "dump---(\$semaphorego2): " . dump($semaphorego2) . "\n\n";  
+					my $semaphorestop1 = $retitem{semaphorestop1}; say TOFILE "dump---(\$semaphorestop1): " . dump($semaphorestop1) . "\n\n";
+					my $semaphorestop2 = $retitem{semaphorestop2}; say TOFILE "dump---(\$semaphorestop2): " . dump($semaphorestop2) . "\n\n";  
+					my $textpattern = $retitem{textpattern}; say TOFILE "dump---(\$textpattern): " . dump($textpattern) . "\n\n";  
+					my $afterlines = $retitem{afterlines}; say TOFILE "dump---(\$afterlines): " . dump($afterlines) . "\n\n";  
 					my ( $semaphore1, $semaphore2 );
 					
 					
@@ -741,41 +741,41 @@ sub report # This function retrieves the results of interest from the texts file
 						open( RETFILE, "$retfile" ) or die( "$!" );
 						my @lines = <RETFILE>;
 						close RETFILE;
-						say TOSHELL "RETFILE! " ;
+						say TOFILE "RETFILE! " ;
 						my $countline = 0;
 						foreach my $line ( @lines )
 						{
 							$line =~ s/^\s+//;
 							chomp $line;
 							$line = $line . " ";
-							#say TOSHELL "\$line: $line";
+							#say TOFILE "\$line: $line";
 							
 							if ( ( not defined( $semaphorego1 ) ) or ( $line =~ m/$semaphorego1/ ) )
 							{
-								$semaphore1 = "on";  say TOSHELL "ON1: ";
+								$semaphore1 = "on";  say TOFILE "ON1: ";
 							}
 							
 							if ( $semaphore1 eq "on" )
 							{
 								if ( ( not defined( $semaphorego2 ) ) or ( $line =~ m/$semaphorego2/ ) )
 								{
-									$semaphore2 = "on"; say TOSHELL "ON2: ";
+									$semaphore2 = "on"; say TOFILE "ON2: ";
 								}
 							}
 														
 							if ( ( $line =~ m/$semaphorestop1/ ) and ( $semaphorestop1 ne "" ) )
 							{
-								$semaphore1 = "off"; say TOSHELL "OFF1: ";
+								$semaphore1 = "off"; say TOFILE "OFF1: ";
 							}
 							
 							if ( ( $line =~ m/$semaphorestop2/ ) and ( $semaphorestop2 ne "" ) )
 							{
-								$semaphore2 = "off"; say TOSHELL "OFF2: ";
+								$semaphore2 = "off"; say TOFILE "OFF2: ";
 							}
 							
 							if ( ( $textpattern ne "" ) and ( $line =~ m/^$textpattern/ ) and ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
 							{
-								print TOSHELL "HIT REPORT1! "; say TOSHELL $line;
+								print TOFILE "HIT REPORT1! "; say TOFILE $line;
 								push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorego1 $semaphorego2 $line " );
 								$semaphore1 = "off";
 								$semaphore2 = "off";
@@ -783,7 +783,7 @@ sub report # This function retrieves the results of interest from the texts file
 							
 							if ( ( $afterlines ne "" ) and ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) and ( $countline == $afterlines ) )
 							{
-								print TOSHELL "HIT REPORT2! "; say TOSHELL $line;
+								print TOFILE "HIT REPORT2! "; say TOFILE $line;
 								push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorestop1 $semaphorestop2 $line " );
 								$countlines = 0;
 								$semaphore1 = "off";
@@ -792,7 +792,7 @@ sub report # This function retrieves the results of interest from the texts file
 							
 							if ( ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
 							{
-								$countline++; say TOSHELL "ON3 COUNTLINE: $countline";
+								$countline++; say TOFILE "ON3 COUNTLINE: $countline";
 							}
 						}
 					}
@@ -801,7 +801,7 @@ sub report # This function retrieves the results of interest from the texts file
 			}
 			$counttool++;
 		}
-		say TOSHELL "\@mergestruct: " . dump(@mergestruct); 
+		say TOFILE "\@mergestruct: " . dump(@mergestruct); 
 		$countinstance++;
 	}
 	
@@ -809,7 +809,7 @@ sub report # This function retrieves the results of interest from the texts file
 	#{ 
 	#	push ( @mergecases,  @repfilemem );
 	#}
-	#say TOSHELL "\@repfilemem ~~ \@mergecases.";
+	#say TOFILE "\@repfilemem ~~ \@mergecases.";
 	
 	say "#Reporting results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $repfile. ";
 		
@@ -817,15 +817,15 @@ sub report # This function retrieves the results of interest from the texts file
 	{
 		foreach my $inst ( @$instref )
 		{
-			print REPFILE "$inst"; #say TOSHELL " INSTANCE " . dump($_);
+			print REPFILE "$inst"; #say TOFILE " INSTANCE " . dump($_);
 		}
 		print REPFILE "\n";
 	}
 	close REPFILE;
 		
-	say TOSHELL "HEREIS \@repcases " . dump(@repcases); say TOSHELL "\@repstruct " . dump(@repstruct); say TOSHELL "\@mergestruct " . dump(@mergestruct);
-	say TOSHELL "\@mergecases " . dump(@mergecases); say TOSHELL "\$repfile: " . dump($repfile);
-	close TOSHELL;
+	say TOFILE "HEREIS \@repcases " . dump(@repcases); say TOFILE "\@repstruct " . dump(@repstruct); say TOFILE "\@mergestruct " . dump(@mergestruct);
+	say TOFILE "\@mergecases " . dump(@mergecases); say TOFILE "\$repfile: " . dump($repfile);
+	close TOFILE;
 	close OUTFILE;
 	return ( \@repcases, \@repstruct, \@mergestruct, \@mergecases, $repfile ); 
 } # END SUB report;
@@ -833,32 +833,32 @@ sub report # This function retrieves the results of interest from the texts file
 sub get_files # UNUSED. LEGACY. CUT.
 {
 	say "Extracting statistics for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", instance: " . ( $countinstance + 1);
-	say TOSHELL "
+	say TOFILE "
 	#Extracting statistics for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", instance: " . ( $countinstance + 1);
 	my ( $themereport, $countcase, $countblock, $counttheme, $countreport, $retfile, $repfile, 
 		$simtitle, $reporttitle, $simdatum, $retrievsref, $countinstance, $swap, $loadsortemps ) = @_;
 		
-	say TOSHELL "#CALLED-REPSTRUCT " . dump(@repstruct); # ZZZ	
-	say TOSHELL "CALLED-\$themereport: " . dump($themereport);
-	say TOSHELL "CALLED-\$countcase: " . dump($countcase);
-	say TOSHELL "CALLED-\$countblock: " . dump($countblock);
-	say TOSHELL "CALLED-\$themereport " . dump($themereport);
-	say TOSHELL "CALLED-\$counttheme " . dump($counttheme);
-	say TOSHELL "CALLED-\$countreport " . dump($countreport);
-	say TOSHELL "CALLED-\$retfile: " . dump($retfile);
-	say TOSHELL "CALLED-\$repfile: " . dump($repfile);
-	say TOSHELL "CALLED-\$loadsortemps " . dump($loadsortemps);
-	say TOSHELL "repfilemem CALLED " . dump( @repfilemem );
+	say TOFILE "#CALLED-REPSTRUCT " . dump(@repstruct); # ZZZ	
+	say TOFILE "CALLED-\$themereport: " . dump($themereport);
+	say TOFILE "CALLED-\$countcase: " . dump($countcase);
+	say TOFILE "CALLED-\$countblock: " . dump($countblock);
+	say TOFILE "CALLED-\$themereport " . dump($themereport);
+	say TOFILE "CALLED-\$counttheme " . dump($counttheme);
+	say TOFILE "CALLED-\$countreport " . dump($countreport);
+	say TOFILE "CALLED-\$retfile: " . dump($retfile);
+	say TOFILE "CALLED-\$repfile: " . dump($repfile);
+	say TOFILE "CALLED-\$loadsortemps " . dump($loadsortemps);
+	say TOFILE "repfilemem CALLED " . dump( @repfilemem );
 				
-	my @repfilemem = @$swap; #say TOSHELL "CALLED-\@repfilemem " . dump(@repfilemem);
+	my @repfilemem = @$swap; #say TOFILE "CALLED-\@repfilemem " . dump(@repfilemem);
 	my @retrievs = @$retrievsref;
 	
-	my @measurements_to_report = $retrievs[0]; #say TOSHELL "CALLED-\@measurements_to_report " . dump(@measurements_to_report);
-	my $dates_to_report = $simtitle; #say TOSHELL "CALLED-\$dates_to_report " . dump($dates_to_report);
+	my @measurements_to_report = $retrievs[0]; #say TOFILE "CALLED-\@measurements_to_report " . dump(@measurements_to_report);
+	my $dates_to_report = $simtitle; #say TOFILE "CALLED-\$dates_to_report " . dump($dates_to_report);
 	
-	say TOSHELL "CALLED\$loadsortemps: " . $loadsortemps; say TOSHELL "\$retfile! " . $retfile;
+	say TOFILE "CALLED\$loadsortemps: " . $loadsortemps; say TOFILE "\$retfile! " . $retfile;
 	open( RETFILE,  "$retfile" ) or die "Can't open $retfile $!";
-	my @lines_to_inspect = <RETFILE>; say TOSHELL "CALLED-\@lines_to_inspect " . dump(@lines_to_inspect);
+	my @lines_to_inspect = <RETFILE>; say TOFILE "CALLED-\@lines_to_inspect " . dump(@lines_to_inspect);
 
 	my @countcolumns;
 	my $countzones = 0;
@@ -871,7 +871,7 @@ sub get_files # UNUSED. LEGACY. CUT.
 			$line_to_inspect =~ s/^\s+//g;### DO THIS? ZZZ
 			$line_to_inspect =~ s/\s*$//;      #remove trailing whitespace
 			#$line_to_inspect =~ s/\ {2,}/ /g;  #remove multiple literal spaces
-			$line_to_inspect =~ s/\t{2,}/\t/g; say TOSHELL "line_to_inspect: $line_to_inspect";		 
+			$line_to_inspect =~ s/\t{2,}/\t/g; say TOFILE "line_to_inspect: $line_to_inspect";		 
 			
 			if ( $themereport eq "temps" ) # NEVER CHECKED IF IT STILL WORKS AFTER SOME USES
 			{
@@ -966,7 +966,7 @@ sub get_files # UNUSED. LEGACY. CUT.
 			}
 			
 			my $line_to_report;
-			say TOSHELL "\$loadsortemps: $loadsortemps";
+			say TOFILE "\$loadsortemps: $loadsortemps";
 			if ( ( $themereport eq "loads" ) or ( $themereport eq "tempsstats" ) ) 
 			{	
 				if ( $line_to_inspect =~ /^$loadsortemps/ )
@@ -981,7 +981,7 @@ sub get_files # UNUSED. LEGACY. CUT.
 			}
 		}
 	}
-	say TOSHELL "LEAVING \@repfilemem " . dump(@repfilemem);
+	say TOFILE "LEAVING \@repfilemem " . dump(@repfilemem);
 	return (@repfilemem); 
 } # END SUB get_files
 
